package at.ac.uibk.gitsearch.security.oauth2;

import at.ac.uibk.gitsearch.GitsearchApp;
import org.junit.Assert;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.mock.web.MockHttpServletRequest;
import org.springframework.mock.web.MockHttpServletResponse;
import org.springframework.security.oauth2.core.endpoint.OAuth2AuthorizationRequest;
import org.springframework.security.oauth2.core.endpoint.OAuth2ParameterNames;

@SpringBootTest(classes = GitsearchApp.class)
public class GitSearchOAuth2AuthorizationRequestRepositoryIT {

    private static final String TEST_STATE = "JustATestState";

    @Autowired
    private GitSearchOAuth2AuthorizationRequestRepository requestRepository;

    @Test
    public void testRepositorySimple() {
        MockHttpServletRequest mockedRequest = new MockHttpServletRequest();
        mockedRequest.addParameter(OAuth2ParameterNames.STATE, TEST_STATE);
        MockHttpServletResponse mockedResponse = new MockHttpServletResponse();

        OAuth2AuthorizationRequest oauthRequest = OAuth2AuthorizationRequest
            .authorizationCode()
            .state(TEST_STATE)
            .authorizationUri("http://unusedHere")
            .clientId("someClientId")
            .build();

        requestRepository.saveAuthorizationRequest(oauthRequest, mockedRequest, mockedResponse);

        OAuth2AuthorizationRequest retrievedRequest = requestRepository.loadAuthorizationRequest(mockedRequest);

        Assert.assertEquals(oauthRequest, retrievedRequest);

        OAuth2AuthorizationRequest deletedRequest = requestRepository.removeAuthorizationRequest(mockedRequest);

        Assert.assertEquals(oauthRequest, deletedRequest);

        Assert.assertNull("it should be removed", requestRepository.removeAuthorizationRequest(mockedRequest));
    }
}
